'use strict';

const path = require('path');

const packageJSON = require('../../package.json');
const rootDir = path.dirname(path.resolve(__dirname, '../../package.json'));

const f2eCiConfig = require('../../f2eci.json');
const PEON_DIST = path.resolve(rootDir, f2eCiConfig.dist);
const WEBPACK_DIST = path.join(rootDir, f2eCiConfig.dist, f2eCiConfig['static-src']);
const PUBLIC_PATH = f2eCiConfig.urlPrefix + f2eCiConfig['static-src'] + '/';

const PREFIX_REGEX = new RegExp(`^${f2eCiConfig.name || packageJSON.name}`);

/**
 * 将action中的staticResource的entry转为结果的绝对路径
 *
 * @param  {String} staticResource - 解析到的静态资源
 * @return {String}
 */
function transformStaticResourceToAbsolutePath(staticResource) {
    if (!staticResource) return '';
    const ret = staticResource.replace(PREFIX_REGEX, PEON_DIST);
    return ret.lastIndexOf('.js') != ret.length - 3 ? `${ret}.js` : ret;
}

/**
 * 将entry的相对路径转为结果的绝对路径
 *
 * @param  {String} relativePath - 相对的路径
 * @return {String}
 */
function transfromSourceToAbsolutePath(relativePath) {
    if (!relativePath) return '';

    return path.resolve(WEBPACK_DIST, relativePath);
}

/**
 * 将entry的绝对路径转为结果的相对路径
 *
 * @param  {String} absolutePath - 绝对路径
 * @return {String}
 */
function transformToRelativePath(absolutePath) {
    const ext = path.parse(absolutePath).ext;
    return path.relative(WEBPACK_DIST, absolutePath).replace(new RegExp(`${ext}$`), '');
}

module.exports = {
    transformStaticResourceToAbsolutePath,
    transfromSourceToAbsolutePath,
    transformToRelativePath,
    WEBPACK_DIST,
    PUBLIC_PATH
};
